#
# spec file for package grsync
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           grsync
Version:        1.3.1
Release:        1.8
Summary:        GUI for rsync
License:        GPL-2.0-only
Group:          Productivity/Archiving/Backup
URL:            http://www.opbyte.it/grsync/
Source:         http://www.opbyte.it/release/%{name}-%{version}.tar.gz
Patch1:         fix-invalid-lc-messages-dir.patch
# PATCH-FIX-UPSTREAM grsync-appdata.patch badshah400@gmail.com -- Add, translate and install appdata file
Patch2:         grsync-appdata.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dos2unix
BuildRequires:  intltool
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
Requires:       rsync
Recommends:     %{name}-lang

%description
Grsync is a GUI (Graphical User Interface) for rsync, the commandline directory
and file synchronization tool. It can be effectively used to synchronize local
directories and it supports remote targets as well (even though it doesn't
support browsing the remote folder). Sample uses of grsync include: synchronize
a music collection with removable devices, backup personal files to a networked
drive, replication of a partition to another one, mirroring of files, etc.

%lang_package

%prep
%autosetup -p1

%build
autoreconf -fi
%configure \
	--disable-unity
pushd po
mv ca_ES.po ca.po
mv cs_CZ.po cs.po
mv de_DE.po de.po
mv es_ES.po es.po
mv fr_FR.po fr.po
mv gl_ES.po gl.po
mv hr_HR.po hr.po
mv hu_HU.po hu.po
mv id_ID.po id.po
mv it_IT.po it.po
mv nb_NO.po nb.po
mv nl_NL.po nl.po
mv ru_RU.po ru.po
mv sv_SE.po sv.po
mv tr_TR.po tr.po
popd
dos2unix README NEWS AUTHORS

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%suse_update_desktop_file -r %{name} Utility Archiving GTK

%files
%license COPYING
%doc AUTHORS README NEWS
%{_bindir}/grsync
%{_bindir}/grsync-batch
%{_datadir}/applications/grsync.desktop
%{_datadir}/pixmaps/grsync.png
%{_datadir}/pixmaps/grsync-busy.png
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-grsync-session.png
%{_datadir}/mime/packages/grsync.xml
%{_mandir}/man1/grsync*
%dir %{_datadir}/appdata
%{_datadir}/appdata/*.appdata.xml

%files lang -f %{name}.lang

%changelog
* Fri Dec 29 2023 jun wang <jgwang@suse.com>
- Update to version 1.3.1
  * Fixed Desktop file compatibility
  * Fixed nested functions with llvm
    (https://sourceforge.net/p/grsync/patches/9/)
  * Modernized glade file (converted to gtk3 3.22 using Glade
    3.38.2, thanks genodeftest)
  * Fixed rsync output not expanding vertically
  * Grsync-batch: added "Halt on failure" support
  * Moved default config directory from user home to .config
  * Some AC updates
  * Added Japanese translation
  * Updated French translation
  * Updated Czech translation
- Update patch fix-invalid-lc-messages-dir.patch because of
  configure.ac replacing configure.in
* Mon Dec 28 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3.0:
  * Gtk3 compatibility (some compile warnings left)
  * Removed Maemo support, platform is obsolete
  * Added escaping of arguments containing spaces when printing
    rsync command line output
  * Updated Spanish translation
- Remove grsync.patch
* Sun Jun  7 2020 olaf@aepfle.de
- Update to 1.2.8
- Fix build with grsync.patch
* Tue Aug  9 2016 badshah400@gmail.com
- Add grsync-appdata.patch to add, translate and install appdata
  file; the presence of the appdata file ensures that the
  application appears on appstores like GNOME Software and KDE
  Discover.
* Wed Mar 23 2016 lazy.kent@opensuse.org
- Update to 1.2.6.
  * Don't save "default" session to ini file when "remember last
    used session" is off.
  * Better "before command" error notification.
  * Added "overwrite logs" preferences option.
  * Updated Norwegian, Russian, German, Swedish, Simplified Chinese
  * translations.
  * Enhanced and translated desktop file.
  * Updated README file.
- Split off and Recommend a -lang package,
- Drop fix-desktop-file.patch: the action is done running
  %%suse_update_desktop_file macro.
- Drop grsync-link-libm.patch: fixed upstream.
- Rebase fix-invalid-lc-messages-dir.patch: add "hu", don't touch
  pt_BR, zh_CN, zh_TW, as they are in their own.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 1.2.5
  * Fixed an uninitialized variable warning
  * Fixed current session type change on new session creation
  * Fixed selection of sessions in set
  * Removed "switch source with destination" keyboard shortcut
  * Fixed pause and stop when running as superuser (it may ask the
    password multiple times)
  * Added Hungarian translation
  * Updated French translation
  * Updated Czech translation
- Use download Url as source
- Update fix-invalid-lc-messages-dir.patch and disable  broken hungarian
  translation
* Thu Jul 11 2013 puzel@suse.com
- update to 1.2.4
  - Monospace font in the rsync output box
  - Log files are now appended (instead of truncated) each time a
    new run is done
  - Added date and time when starting a new rsync run (useful with
    logs)
  - Added Traditional Chinese translation (thanks Wei-Lun)
* Mon Apr 22 2013 puzel@suse.com
- update to 1.2.3
  - Do not allow creation of session names with slashes in them
  - Lintian fixes to man pages and desktop file (thanks Martijn)
* Tue Oct 23 2012 puzel@suse.com
- update to 1.2.2
  - increased size of source and destination fields
  - updated translations
* Mon Jan 23 2012 puzel@suse.com
- update to 1.2.1
  - enabled session sets
  - fixed saving of current session when creating new one
  - little fix to main window layout for the two "open" buttons,
  which had some overflown translations
  - grsync-batch: fixed paths with spaces in them
  - optimization of global and file progress updates
  - fixed a translation problem on the "slashes" help dialog
  - fixed bug: didn't check "before command" exit status correctly
  - fixed bug: some rsync window titles aren't translatable
  - fixed bug: grsync-batch can't find last session in config file
  - fixed bug: output text is not selectable after something
  initially fails
  - added check for empty new session names
  - differentiated exit status in grsync-batch
  - some glade file cleanups "by-hand"
  - auto window resize only on first window load
- configure with --disable-unity
- add grsync-link-libm.patch (fix build)
* Tue Apr 26 2011 puzel@novell.com
- use spec-cleaner
* Fri May  7 2010 puzel@novell.com
- update to grsync-1.1.1
  * Removed automatic addition of a trailing slash to source and
    destination directories
  * Updated new functionalities of 1.1.0 for Maemo, added
    configuration backup support + other fixes
  * Updated czech translation (thanks Lucas)
  * Fixed tags in a french translation message
  * Added "Rsync command line" menu item
* Tue Mar 30 2010 puzel@novell.com
- update to grsync-1.1.0
  - notable changes:
  * "Use tray icon" preferences option added
  * Added --protect-args option, on by default, solves the
    "remote filename with spaces" problem
  * Fixed bug: doesn't save "itemized changes list" option
  * Added mime type definition for grsync session files with icon
  * Updated desktop file to open session files with "grsync -i"
  * Made some fixes which could make grsync more stable on some systems
  * Added "run as superuser" extra options switch, uses "pkexec"
    from policykit
  * Added rsync child watch function
  * Added rsync process exit status output
  * Fixed behaviour when rsync window is closed not by using the close button
  * Fixed scrolling to end on pause
  * Added -i option to import a session file from command line
* Thu Dec  3 2009 puzel@novell.com
- update to grsync-0.9.3
  * Fixed file permissions: some scripts were not executable
  * Fixed main window position and size reset when closed with window manager's close button
  * Added advanced option to disable directory recursion
  * Added preferences option to enable the "switch source with destination" button
  * New main window layout, more compact and pretty; changes include:
  * new toolbar
  * removed quit button
  * introduced more stock buttons
  * removed custom icons from buttons
  * additional options in a multiline text entry field
  * directories moved to "basic options" tab
  * notes moved to "extra options" tab
  * other little fixes to tooltips, accelerators etc.
  * Authors information moved from AUTHORS file to about dialog
* Wed Oct  7 2009 puzel@novell.com
- update to grsync-0.9.2
  * grsync-batch: added itemize-changes option which was missing
    in 0.9.1
  * Small fix to the pause button showing as "play" instead of
    "pause" in some occasions
  * Catalan translation added (thanks Josep)
  * "-s" command line option added, stays open on success
  * Gtkbuilder xml file updated for glade 3.6.7
  * Fixed bug: when wrong session specified on the command line
    with "-e", executes default session instead of nothing
  * Fixed bug: grsync can't start when compiled against
    gtk >= 2.16.6
  * Now prints an error and exits when unable to correctly load
    gtkbuilder xml file
  * Dutch translation updated (thanks Frank)
  * Italian translation updated
  * Manpage updated
* Fri Jun 26 2009 puzel@suse.cz
- update to grsync-0.9.1
  * "itemize-changes" advanced rsync option added
  * some code cleanup
  * added "warning" button which opens the error list
  * made "show error list when finished" preferences option default to false
  * fixed some small memory leaks
  * some cosmetic fixes
  * focus on widgets didn't work before the window loosed focus
* Tue Jun  9 2009 puzel@suse.cz
- update to 0.9.0
  * Converted from glade-2 with code generation to glade-3 with GtkBuilder
  * Some deprecated GTK calls have been removed, now grsync requires GTK 2.16
  * Found an acceptable way to make rsync window resizable, despite the
    presence of an expander
  * Removed "switch source with destination" button (there is a menu item for
    the same purpose)
  * Added "fast rsync scrolling" preferences switch
  * Added extra option "on rsync error only" to limit the execution of the
    "after" command
  * Italian translation updated (the others will need some work because of the
    move to GtkBuilder)
  * "Notes" session field added
  * Error dialog is now marked ad "urgent"
  * New session dialog remembers last session name
  * System menu: moved from applications/network to applications/system
  * New bigger icon
* Sat May 23 2009 puzel@suse.cz
- initial package (version 0.6.3)
